@@ -167,7 +167,8 @@ class Cell(object):
         
         #Not sure if all of these are needed, just precautions
         neuron.h('objref axonlist, dendlist, apicdendlist')
-        neuron.h('objref somalist, allseclist, alldendlist')
+        neuron.h('objref somalist, alldendlist')
+        #neuron.h('objref allseclist')
         neuron.h.somalist = None
         neuron.h.dendlist = None
         neuron.h.axonlist = None
@@ -244,6 +245,7 @@ class Cell(object):
         #recreate sectionlists in case something changed
         neuron.h.define_shape()
         self._create_sectionlists()
+
     
     def _set_nsegs(self, nsegs_method, lambda_f, max_nsegs_length):
         '''Set number of segments per section according to the lambda-rule,
@@ -283,6 +285,29 @@ class Cell(object):
         self.dendlist = neuron.h.SectionList()
         self.apiclist = neuron.h.SectionList()
         
+        # Update the local lists
+        self._update_local_seclists()
+
+        #list with all sections
+        self.allseclist = neuron.h.SectionList()
+        for sec in self.somalist:
+            self.allseclist.append(sec)
+        for sec in self.dendlist:
+            self.allseclist.append(sec)
+        for sec in self.apiclist:
+            self.allseclist.append(sec)
+        for sec in self.axonlist:
+            self.allseclist.append(sec)
+        
+        #list with all dendritic sections
+        self.alldendlist = neuron.h.SectionList()
+        for sec in self.dendlist:
+            self.alldendlist.append(sec)
+        for sec in self.apiclist:
+            self.alldendlist.append(sec)
+            
+    def _update_local_seclists(self):
+        '''Update "local" section lists'''
         if neuron.h.sec_counted == 0:
             self.nsomasec = 0
             #Place sections in lists
@@ -311,24 +336,6 @@ class Cell(object):
                     self.axonlist.append(sec)
             except:
                 pass
-        
-        #list with all sections
-        self.allseclist = neuron.h.SectionList()
-        for sec in self.somalist:
-            self.allseclist.append(sec)
-        for sec in self.dendlist:
-            self.allseclist.append(sec)
-        for sec in self.apiclist:
-            self.allseclist.append(sec)
-        for sec in self.axonlist:
-            self.allseclist.append(sec)
-        
-        #list with all dendritic sections
-        self.alldendlist = neuron.h.SectionList()
-        for sec in self.dendlist:
-            self.alldendlist.append(sec)
-        for sec in self.apiclist:
-            self.alldendlist.append(sec)
     
     def _get_idx(self, seclist):
         '''Return boolean vector which indexes where segments in seclist 
@@ -473,7 +480,14 @@ class Cell(object):
                     command = cmd1 + pptype + cmd2  
                     exec(command)
                     for param in kwargs.keys():
-                        exec('stim.' + param + '=' + str(kwargs[param]))
+                        try:
+                            exec('stim.' + param + '=' + str(kwargs[param]))
+                        except SyntaxError:
+                            ERRMSG = ''.join(['',
+                                     'Point process type "{0}" might not '.format(pptype),
+                                     'recognize attribute "{0}". '.format(param),
+                                     'Check for misspellings'])
+                            raise Exception, ERRMSG                            
                     self.stimlist.append(stim)
                     
                     #record current
@@ -629,17 +643,19 @@ class Cell(object):
         '''
         poss_idx = self.get_idx(section=section, z_min=z_min, z_max = z_max)
         idx = np.empty(nidx, dtype=int)
+        norm_area_cumsum = np.cumsum(self.area[poss_idx] / 
+                                     sum(self.area[poss_idx]))
         
         for i in xrange(nidx):
-            idx[i] = np.min(np.nonzero(np.random.rand() < \
-                np.cumsum(self.area[poss_idx]/sum(self.area[poss_idx])))[0])
+            idx[i] = np.nonzero(np.random.rand() < norm_area_cumsum)[0].min()
         
         return poss_idx[idx]
     
     def simulate(self, electrode=None, rec_imem=False, rec_vmem=False,
                  rec_ipas=False, rec_icap=False,
                  rec_isyn=False, rec_vmemsyn=False, rec_istim=False,
-                 rec_variables=[]):
+                 rec_variables=[], variable_dt=False, atol=0.001,
+                 to_memory=True, to_file=False, file_name=None):
         '''
         This is the main function running the simulation of the NEURON model.
         Start NEURON simulation and record variables specified by arguments.
@@ -660,6 +676,11 @@ class Cell(object):
             rec_vmemsyn:    record membrane voltage of segments with Synapse
             rec_istim:  record currents of StimIntraElectrode
             rec_variables: list of variables to record, i.e arg=['cai', ]
+            variable_dt: boolean, using variable timestep in NEURON
+            atol:       absolute tolerance used with the variable timestep in NEURON
+            to_memory:  only valid with electrode, store lfp in -> electrode.LFP 
+            to_file:    only valid with electrode, save LFPs in hdf5 file format 
+            file_name:  name of hdf5 file, '.h5' is appended if it doesnt exist 
         '''
         self._set_soma_volt_recorder()
         self._collect_tvec()
@@ -680,11 +701,12 @@ class Cell(object):
             if not rec_imem:
                 print "rec_imem = %s, membrane currents will not be recorded!" \
                                   % str(rec_imem)
-            _run_simulation(self)
+            _run_simulation(self, variable_dt, atol)
         else:
             if self.timeres_NEURON != self.timeres_python:
                 raise ValueError, 'timeres_NEURON != timeres_python'
-            _run_simulation_with_electrode(self, electrode)
+            _run_simulation_with_electrode(self, electrode, variable_dt, atol,
+                                           to_memory, to_file, file_name)
         
         #somatic trace
         self.somav = np.array(self.somav)
@@ -799,7 +821,7 @@ class Cell(object):
             i += 1
         del self.recvariablesreclist
     
-    def loadspikes(self):
+    def _loadspikes(self):
         '''
         Initialize spiketimes from netcon if they exist
         '''
