@@ -1,6 +1,7 @@
 /* Created by Language version: 6.2.0 */
 /* VECTORIZED */
 #include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 #include "scoplib.h"
 #undef PI
@@ -255,7 +256,7 @@ static void nrn_alloc(_prop)
  	hoc_register_cvode(_mechtype, _ode_count, _ode_map, _ode_spec, _ode_matsol);
  	hoc_register_tolerance(_mechtype, _hoc_state_tol, &_atollist);
  	hoc_register_var(hoc_scdoub, hoc_vdoub, hoc_intfunc);
- 	ivoc_help("help ?1 na /Users/ehagen/Work/LFPy-release/examples/x86_64/na.mod\n");
+ 	ivoc_help("help ?1 na /Users/ehagen/Work/LFPy-release/trunk/examples/x86_64/na.mod\n");
  hoc_register_limits(_mechtype, _hoc_parm_limits);
  hoc_register_units(_mechtype, _hoc_parm_units);
  }
